;; Generated package description from cursor-undo.el  -*- no-byte-compile: t -*-
(define-package "cursor-undo" "1.0.0.20240721.171240" "Undo Cursor Movement" '((cl-lib "0.5")) :commit "bbe2c5a6de06d8ae6881b4a11eb74008334251b0" :url "https://elpa.gnu.org/packages/cursor-undo.html" :authors '(("Luke Lee" . "luke.yx.lee@gmail.com")) :maintainer '("Luke Lee" . "luke.yx.lee@gmail.com") :keywords '("undo" "cursor"))
